@@ -1,3 +1,8 @@
+""" Object abstraction.
+
+This modules containes all the abstraction for code object manipulated by pycodeanalyzer
+"""
+
 from __future__ import annotations
 
 import re
@@ -6,12 +11,20 @@ from typing import Any, Dict, List, Tuple
 
 
 class AbstractObjectLanguage(Enum):
+    """Language of the code source
+
+    Enum representing supported languages
+    """
+
     Unknown = 0
     CPP = 1
     Python = 2
+    Java = 3
 
 
 class AbstractObject:
+    """Base of all abstraction"""
+
     def __init__(self, name: str, origin: str) -> None:
         self.name = name
         self.type = "Object"
@@ -24,6 +37,8 @@ class AbstractObject:
 
 
 class AbstractEnum(AbstractObject):
+    """Enum abstraction"""
+
     def __init__(self, name: str, namespace: str, origin: str, values: List[str]):
         super().__init__(name, origin)
         self.namespace = namespace
@@ -43,6 +58,8 @@ class AbstractEnum(AbstractObject):
 
 
 class AbstractFunction(AbstractObject):
+    """Function abstraction"""
+
     def __init__(
         self,
         name: str,
@@ -78,6 +95,7 @@ class AbstractFunction(AbstractObject):
 
 
 class AbstractClass(AbstractObject):
+    """Class abstraction"""
 
     NonObjectTypes: Dict[AbstractObjectLanguage, List[str]] = {
         AbstractObjectLanguage.Unknown: [],
@@ -126,6 +144,26 @@ class AbstractClass(AbstractObject):
             "long",
             "bool",
         ],
+        AbstractObjectLanguage.Java: [
+            "void",
+            "byte",
+            "int",
+            "short",
+            "long",
+            "float",
+            "double",
+            "boolean",
+            "char",
+            "String",
+            "Object",
+            "Integer",
+            "Short",
+            "Long",
+            "Float",
+            "Double",
+            "Boolean" "Byte" "Char",
+            "Void",
+        ],
     }
 
     def __init__(self, name: str, namespace: str, origin: str) -> None:
@@ -139,6 +177,12 @@ class AbstractClass(AbstractObject):
     def addMember(self, type: str, name: str, visibility: str) -> None:
         self.members.append((type, name, visibility))
 
+    def hasMember(self, name: str) -> bool:
+        for item in self.members:
+            if item[1] == name:
+                return True
+        return False
+
     def addMethod(
         self,
         returnType: str,
@@ -241,6 +285,8 @@ class AbstractClass(AbstractObject):
             .replace("...", "")
             .replace("enum", "")
             .replace("struct", "")
+            .replace("[", "")
+            .replace("]", "")
             .strip()
         )
 
@@ -279,5 +325,14 @@ class AbstractClass(AbstractObject):
             print("\t\t * {2} {0} {1}".format(tuple[0], tuple[1], tuple[2]))
 
 
+def platformIndependantPathHash(path: str) -> str:
+    return path.replace("\\", "/").replace("/", "").replace("_", "").replace(":", "")
+
+
 def compareAbstractObject(obj: AbstractObject) -> Tuple[str, str, str]:
-    return (obj.type, obj.origin, obj.name)
+    """Comparison operator to sort AbstractObject and subclasses
+
+    This allow to sort by type, origin and name
+    """
+
+    return (obj.type, platformIndependantPathHash(obj.origin), obj.name)
