@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from typing import List, Optional, Tuple
 
 from pycodeanalyzer.core.abstraction.objects import (
     AbstractClass,
@@ -8,6 +8,8 @@ from pycodeanalyzer.core.abstraction.objects import (
 
 
 class DependancyAnalyser:
+    """Analyzer for object dependancies"""
+
     def analyze(
         self,
         klasses: List[AbstractClass],
@@ -30,7 +32,7 @@ class DependancyAnalyser:
                 typeName = type[lastSeparatorIndx + 2 :]
             else:
                 typeName = type
-            linkedClass = self.findClass(
+            linkedClass = self.__findClass(
                 typeDeclaredNamespace,
                 typeName,
                 klasses,
@@ -38,7 +40,7 @@ class DependancyAnalyser:
                 target.name,
                 target.usingNS,
             )
-            linkedEnum = self.findEnum(
+            linkedEnum = self.__findEnum(
                 typeDeclaredNamespace,
                 typeName,
                 enums,
@@ -58,7 +60,27 @@ class DependancyAnalyser:
                 )
         return (target, linkedClasses, linkedEnums, linkedFunctions)
 
-    def findClass(
+    def getParent(
+        self, klasses: List[AbstractClass], target: AbstractClass, parentName: str
+    ) -> Optional[AbstractClass]:
+        typeDeclaredNamespace = ""
+        typeName = ""
+        if "::" in parentName:
+            lastSeparatorIndx = parentName.rindex("::")
+            typeDeclaredNamespace = parentName[:lastSeparatorIndx]
+            typeName = parentName[lastSeparatorIndx + 2 :]
+        else:
+            typeName = parentName
+        return self.__findClass(
+            typeDeclaredNamespace,
+            typeName,
+            klasses,
+            target.namespace,
+            target.name,
+            target.usingNS,
+        )
+
+    def __findClass(
         self,
         namespace: str,
         name: str,
@@ -66,7 +88,7 @@ class DependancyAnalyser:
         currentNamespace: str,
         currentClassName: str,
         usingNS: List[str],
-    ) -> AbstractClass:
+    ) -> Optional[AbstractClass]:
         for klass in klasses:
             if klass.namespace == namespace and klass.name == name:
                 return klass
@@ -102,7 +124,7 @@ class DependancyAnalyser:
                     return klass
         return None
 
-    def findEnum(
+    def __findEnum(
         self,
         namespace: str,
         name: str,
@@ -110,7 +132,7 @@ class DependancyAnalyser:
         currentNamespace: str,
         currentClassName: str,
         usingNS: List[str],
-    ) -> AbstractEnum:
+    ) -> Optional[AbstractEnum]:
         for enum in enums:
             if enum.namespace == namespace and enum.name == name:
                 return enum
