@@ -4,11 +4,16 @@ from typing import Dict, List, Tuple
 
 
 class SearchAnalyser:
+    """Search analyser
+
+    This class allow to search tokens with context in each parsed source file.
+    """
+
     def searchInAllFiles(self, token: str, files: List[str]) -> List[Tuple[str, str]]:
         self.results: List[Tuple[str, str]] = []
         self.threads: List[Thread] = []
         for file in files:
-            thread = Thread(target=self.seachInFileThreaded, args=(token, file))
+            thread = Thread(target=self.__seachInFileThreaded, args=(token, file))
             self.threads.append(thread)
             thread.start()
         for thread in self.threads:
@@ -18,7 +23,12 @@ class SearchAnalyser:
     def seachInFile(self, token: str, filePath: str) -> List[Tuple[str, str]]:
         res: List[Tuple[str, str]] = []
         with open(filePath, "r") as file:
-            enumeration: Dict[int, str] = dict((i, j) for i, j in enumerate(file))
+            text = file.read().splitlines()
+            print(text)
+            enumeration: Dict[int, str] = dict(
+                (i, j + "\n") for i, j in enumerate(text)
+            )
+            print(enumeration)
             for linenb, line in enumeration.items():
                 if re.search(token.lower(), line.lower()):
                     context = ""
@@ -28,5 +38,5 @@ class SearchAnalyser:
                     res.append((filePath, context))
         return res
 
-    def seachInFileThreaded(self, token: str, filePath: str) -> None:
+    def __seachInFileThreaded(self, token: str, filePath: str) -> None:
         self.results.extend(self.seachInFile(token, filePath))
