@@ -1,4 +1,9 @@
-from typing import Any, List, Tuple
+"""Mermaid.js diagram language
+
+This module allow to create mermaid.js class diagram from abstractions.
+"""
+
+from typing import List, Tuple
 
 from pycodeanalyzer.core.abstraction.objects import (
     AbstractClass,
@@ -9,6 +14,8 @@ from pycodeanalyzer.core.abstraction.objects import (
 
 
 class ClassDiagramBuild:
+    """Mermaid.js class diagram builder"""
+
     def __init__(self) -> None:
         self.reset()
 
@@ -17,7 +24,7 @@ class ClassDiagramBuild:
         self.enums: List[AbstractEnum] = []
         self.relations: List[Tuple[str, str]] = []
         self.parents: List[Tuple[str, str]] = []
-        self.target: Any = None
+        self.target: AbstractObject = None
 
     def createClass(
         self,
@@ -27,20 +34,20 @@ class ClassDiagramBuild:
         linkedFunctions: List[AbstractFunction],
     ) -> None:
         self.target = target
-        self.addClass(target)
+        self.__addClass(target)
         for klass in linkedClasses:
-            self.addClass(klass)
+            self.__addClass(klass)
             if target.isParent(klass):
-                self.addInheritance(target, klass)
+                self.__addInheritance(target, klass)
             else:
-                self.addDependancy(target, klass)
+                self.__addDependancy(target, klass)
         for enum in linkedEnums:
-            self.addEnum(enum)
-            self.addDependancy(target, enum)
+            self.__addEnum(enum)
+            self.__addDependancy(target, enum)
 
     def createEnum(self, target: AbstractEnum) -> None:
         self.target = target
-        self.addEnum(target)
+        self.__addEnum(target)
 
     def build(self) -> str:
         res = "classDiagram\n"
@@ -53,21 +60,21 @@ class ClassDiagramBuild:
             res += "<<Class>>\n"
             for member in klass.members:
                 res += (
-                    self.getVisibilityMark(member[2])
+                    self.__getVisibilityMark(member[2])
                     + " "
-                    + (self.getTypeString(member[0]) + " " + member[1] + "\n")
+                    + (self.__getTypeString(member[0]) + " " + member[1] + "\n")
                 )
             for method in klass.methodes:
                 paramstr = ""
                 for param in method[2]:
-                    paramstr += self.getTypeString(param[0]) + " " + param[1] + ", "
+                    paramstr += self.__getTypeString(param[0]) + " " + param[1] + ", "
                 res += (
-                    self.getVisibilityMark(method[3])
+                    self.__getVisibilityMark(method[3])
                     + method[1]
                     + "("
                     + paramstr[:-2]
                     + ") "
-                    + self.getTypeString(method[0])
+                    + self.__getTypeString(method[0])
                     + "\n"
                 )
             res += "}\n"
@@ -91,36 +98,36 @@ class ClassDiagramBuild:
             res += relation[0] + " ..> " + relation[1] + "\n"
         return res
 
-    def addInheritance(
+    def __addInheritance(
         self, target: AbstractClass, linkedObject: AbstractObject
     ) -> None:
         relation = (target.name, linkedObject.name)
         if relation not in self.parents:
             self.parents.append(relation)
 
-    def addDependancy(
+    def __addDependancy(
         self, target: AbstractObject, linkedObject: AbstractObject
     ) -> None:
         relation = (target.name, linkedObject.name)
         if relation not in self.relations:
             self.relations.append(relation)
 
-    def addClass(self, abstractClass: AbstractClass) -> None:
+    def __addClass(self, abstractClass: AbstractClass) -> None:
         if abstractClass not in self.klasses:
             self.klasses.append(abstractClass)
 
-    def addEnum(self, abstractEnum: AbstractEnum) -> None:
+    def __addEnum(self, abstractEnum: AbstractEnum) -> None:
         if abstractEnum not in self.enums:
             self.enums.append(abstractEnum)
 
-    def getVisibilityMark(self, text: str) -> str:
+    def __getVisibilityMark(self, text: str) -> str:
         if text == "private":
             return "-"
         if text == "protected":
             return "#"
         return "+"
 
-    def getTypeString(self, type: str) -> str:
+    def __getTypeString(self, type: str) -> str:
         res = type
         if type.count("<") >= 2:
             # Mermaid does'nt support nested ~ so we do a workaround
