@@ -5,9 +5,13 @@ from pycodeanalyzer.core.logging.loggerfactory import LoggerFactory
 
 
 class Analyzer:
-    def __init__(self) -> None:
-        self.logger = LoggerFactory.createLogger(__name__)
+    """Base class for language analyzer."""
+
+    def __init__(self, name: str) -> None:
+        self.logger = LoggerFactory.createLogger(name)
 
     def analyze(self, rootDir: str, path: str) -> List[AbstractObject]:
         self.logger.error("Use of abstract method : analyze from Analyzer class")
-        return []
+        raise NotImplementedError(
+            "A subclass should be defined and implement this interface"
+        )
