@@ -1,9 +1,10 @@
 import argparse
 import io
 import re
-from typing import Any, List
+from typing import Any, List, Optional
 
 import CppHeaderParser
+from injector import inject
 from pcpp import Action, OutputDirective, Preprocessor
 
 from pycodeanalyzer.core.abstraction.objects import (
@@ -13,6 +14,7 @@ from pycodeanalyzer.core.abstraction.objects import (
     AbstractObject,
     AbstractObjectLanguage,
 )
+from pycodeanalyzer.core.configuration.configuration import Configuration
 from pycodeanalyzer.core.encoding.encodings import Encoding
 from pycodeanalyzer.core.languages.analyzer import Analyzer
 
@@ -129,8 +131,14 @@ class CustomCppHeader(CppHeaderParser.CppHeader):
 
 
 class CppAnalyzer(Analyzer):
-    def __init__(self) -> None:
-        super().__init__()
+    """Analyzer for C/CPP code.
+
+    Handle C/CPP code using PCPP preprocessor and CppHeaderParser.
+    """
+
+    @inject
+    def __init__(self, config: Configuration) -> None:
+        super().__init__(__name__)
         CppHeaderParser.CppHeaderParser.ignoreSymbols = []
         CppHeaderParser.CppHeaderParser.is_enum_namestack = (
             CustomCppHeader.is_enum_namestack
@@ -141,15 +149,25 @@ class CppAnalyzer(Analyzer):
         self.objectPaths: List[str] = []
         self.encoding: Encoding = Encoding()
         self.forceIgnoredSymbols: List[str] = []
+        self.configuration = config
+        self.configured = False
+        self.defines: List[str] = []
+        self.defineConfig()
 
     def analyze(self, rootDir: str, path: str) -> List[AbstractObject]:
         abstractObjects: List[AbstractObject] = []
         self.logger.info("Analysing %s", path)
 
+        if not self.configured:
+            self.handleConfigation()
+
         encoding: str = self.encoding.getFileEncoding(path)
 
         try:
             preproc: CustumCppPreprocessor = CustumCppPreprocessor()
+            for define in self.defines:
+                self.logger.debug("Define : %s", define)
+                preproc.define(define)
             preproc.parseFile(path)
             code: str = preproc.getResult()
 
@@ -315,7 +333,7 @@ class CppAnalyzer(Analyzer):
 
     def extractUnexpectedFromParseError(
         self, err: CppHeaderParser.CppHeaderParser.CppParseError
-    ) -> str:
+    ) -> Optional[str]:
         msg = str(err)
         startDelim = "evaluating"
         endDelim = ":"
@@ -324,3 +342,14 @@ class CppAnalyzer(Analyzer):
         token = msg[msg.index(startDelim) + len(startDelim) :]
         token = token[: token.index(endDelim) - 1].replace("'", "").strip()
         return token
+
+    def defineConfig(self) -> None:
+        self.configuration.defineConfig(
+            "Parser.CPP",
+            "defines",
+            'All value to be define when preprosession : List of name[ value]. Example : ["toto 1","titi \'hello\'", "tata"]',
+        )
+
+    def handleConfigation(self) -> None:
+        defines_val = self.configuration.getList("Parser.CPP", "defines")
+        self.defines = defines_val if defines_val else []
